<?php
function renderRateSort(&$render,$start=0) {
	require_once("render/thumb.php");
	require_once("render/header.php");
	$render->setSelection(array('RateSort'=>'t'),true);
	$render->setView(array('RateSort'=>'t',
						   'Start'=>$start),true);
	list($count,$pictures) = 
		$render->ct->getRateSort(
			$render->uid,$start,
			$render->nbThumbsPerPage);
	$render->setTitle(_("Rating sort"));
	$render->topTitle .= " ".countString($render,$start,$count);
	$render->showSort = false;
	$render->show('<div class="normal">');
	showThumbs($render,$pictures,$start,$count);
	$render->show('</div>');
}

function renderPictureInRateSort(&$render,$pictureID, $position) {
	require_once("render/picture.php");
	$render->setSelection(array('RateSort'=>'t'),true);
	$render->setView(array('RateSort'=>'t',
						 'PictureID'=>$pictureID,
						 'Position'=>$position),true);
	if ($pictures = $render->ct->getPictureInRateSort($pictureID,$position, $render->uid)) {
		_renderPicture(
			$render,
			$pictures['current'], 
			$pictures['prev'], 
			$pictures['next'], 
			$position,
			$pictures['last']);
	}
}
?>